@@ -7,19 +7,10 @@ use std::{
     task::{Context, Poll},
 };
 
-use crate::{
-    buffer_unordered_batch_poller_macro,
-    receiver::{Action, Event, ReciveTypedReceiver, SendUntypedReceiver},
-    receivers::{fix_type, Request},
-};
-use futures::{stream::FuturesUnordered, Future, StreamExt};
+use crate::{AsyncBatchHandler, Bus, Message, Untyped, buffer_unordered_batch_poller_macro, builder::ReceiverSubscriberBuilder, error::{Error, SendError, StdSyncSendError}, receiver::{Action, Event, ReciveTypedReceiver, SendUntypedReceiver, SendTypedReceiver}, receivers::{fix_type, Request}};
 
 use super::{BufferUnorderedBatchedConfig, BufferUnorderedBatchedStats};
-use crate::{
-    builder::ReceiverSubscriberBuilder,
-    receiver::{SendError, SendTypedReceiver},
-    AsyncBatchHandler, Bus, Message, Untyped,
-};
+use futures::{stream::FuturesUnordered, Future, StreamExt};
 use parking_lot::Mutex;
 use tokio::sync::mpsc;
 
@@ -37,23 +28,23 @@ buffer_unordered_batch_poller_macro!(
     |bus, ut: Arc<T>| { async move { ut.sync(&bus).await } }
 );
 
-pub struct BufferUnorderedBatchedAsync<M, R = (), E = crate::error::Error>
+pub struct BufferUnorderedBatchedAsync<M, R, E>
 where
     M: Message,
     R: Message,
-    E: crate::Error,
+    E: StdSyncSendError,
 {
     tx: mpsc::UnboundedSender<Request<M>>,
     stats: Arc<BufferUnorderedBatchedStats>,
     srx: Mutex<mpsc::UnboundedReceiver<Event<R, E>>>,
 }
 
-impl<T, M, R, E> ReceiverSubscriberBuilder<T, M, R, E> for BufferUnorderedBatchedAsync<M, R, E>
+impl<T, M, R> ReceiverSubscriberBuilder<T, M, R, T::Error> for BufferUnorderedBatchedAsync<M, R, T::Error>
 where
-    T: AsyncBatchHandler<M, Response = R, Error = E> + 'static,
+    T: AsyncBatchHandler<M, Response = R> + 'static,
+    T::Error: StdSyncSendError + Clone,
     R: Message,
     M: Message,
-    E: crate::Error,
 {
     type Config = BufferUnorderedBatchedConfig;
 
@@ -80,7 +71,7 @@ where
 
         let poller = Box::new(move |ut| {
             Box::new(move |bus| {
-                Box::pin(buffer_unordered_batch_poller::<T, M, R, E>(
+                Box::pin(buffer_unordered_batch_poller::<T, M, R>(
                     rx,
                     bus,
                     ut,
@@ -92,7 +83,7 @@ where
         });
 
         (
-            BufferUnorderedBatchedAsync::<M, R, E> {
+            BufferUnorderedBatchedAsync::<M, R, T::Error> {
                 tx,
                 stats,
                 srx: Mutex::new(srx),
@@ -106,7 +97,7 @@ impl<M, R, E> SendUntypedReceiver for BufferUnorderedBatchedAsync<M, R, E>
 where
     M: Message,
     R: Message,
-    E: crate::Error,
+    E: StdSyncSendError,
 {
     fn send(&self, m: Action) -> Result<(), SendError<Action>> {
         match self.tx.send(Request::Action(m)) {
@@ -121,7 +112,7 @@ impl<M, R, E> SendTypedReceiver<M> for BufferUnorderedBatchedAsync<M, R, E>
 where
     M: Message,
     R: Message,
-    E: crate::Error,
+    E: StdSyncSendError,
 {
     fn send(&self, mid: u64, m: M) -> Result<(), SendError<M>> {
         match self.tx.send(Request::Request(mid, m)) {
@@ -140,7 +131,7 @@ impl<M, R, E> ReciveTypedReceiver<R, E> for BufferUnorderedBatchedAsync<M, R, E>
 where
     M: Message,
     R: Message,
-    E: crate::Error,
+    E: StdSyncSendError,
 {
     fn poll_events(&self, ctx: &mut Context<'_>) -> Poll<Event<R, E>> {
         let poll = self.srx.lock().poll_recv(ctx);
